#!/bin/bash

# With this script you can create an address label from a LaTeX document
# you must install the following packages:
# sudo aptitude install texlive texlive-doc-de texlive-latex-extra \
#       texlive-lang-german imagemagick poppler-utils

if [ -z "$1" ]; then
    echo "No tex file"
    exit 1
elif [ ! -f "$1" ]; then
    echo "Invalid file"
    exit 1
else
    tex_file="$1"
fi

# if your printer is connected via a print server, check if it's reachable
# else leave it commented out
#if [[ $(ping -c 2 192.168.2.3 2>&1) != *64*bytes*from* ]]; then
#    echo "The printer is not accessible"
#    exit 2
#fi

# create pdf file
pdflatex "$tex_file"
pdf_file="${tex_file:0:${#tex_file}-4}.pdf"
if [ ! -f "$pdf_file" ]; then
    echo "LaTeX compile error, $pdf_file does not exist"
    exit 3
fi
rm "${pdf_file:0:${#pdf_file}-4}.aux" "${pdf_file:0:${#pdf_file}-4}.log"

# give me the chance to view the latex output
# press ctrl + c if you want to cancel
read -p "press ENTER to proceed, ctrl+c to cancel" -e input
# view the pdf file contents in vim
pdftotext -layout "$pdf_file" - | vim -
# press ctrl + c if you want to cancel now
read -p "press ENTER to proceed, ctrl+c to cancel" -e input

png_file="${tex_file:0:${#tex_file}-4}.png"
convert -density 200 "$pdf_file" "$png_file"
rm "$pdf_file"
if [ ! -f "$png_file" ]; then
    echo "The image could not be created"
    exit 4
fi

# now, you must add a method to print the created image
# if you use your printer with CUPS the print command could look like
# lp "$png_file"
# works only, if the barcode printer is the standard one
echo "printed successfully"
exit 0
